C $Header: /u/gcmpack/MITgcm/pkg/dic/phos_flux.F,v 1.9 2008/04/07 20:31:17 dfer Exp $
C $Name:  $

#include "PTRACERS_OPTIONS.h"
#include "DARWIN_OPTIONS.h"
#include "OFFLINE_OPTIONS.h"
CBOP
C !ROUTINE: FE_REMIN_INORG

C !INTERFACE: ==========================================================
      SUBROUTINE FE_REMIN_INORG( freefe, 
     I           Kscavin, FEremin_inorg, WFE_inorg,  
     I           bi,bj,imin,imax,jmin,jmax,
     I           myIter,myTime,myThid)

C !DESCRIPTION:
C Calculate the Fe flux to depth from dust deposition and inorg scavenging 

C !USES: ===============================================================
      IMPLICIT NONE
#include "SIZE.h"
#include "DYNVARS.h"
#include "EEPARAMS.h"
#include "PARAMS.h"
#include "GRID.h"
#include "DARWIN_IO.h"
#include "DARWIN_PARAMS.h"
#include "MONOD_SIZE.h"
#include "MONOD.h"
C !INPUT PARAMETERS: ===================================================
C  myThid               :: thread number
C  myIter               :: current timestep
C  myTime               :: current time
C  BIOac                :: biological productivity
      INTEGER myIter
      _RL myTime
      INTEGER myThid
      _RL  BIOac(1-OLx:sNx+OLx,1-OLy:sNy+OLy,Nr)
      INTEGER imin, imax, jmin, jmax, bi, bj

C !OUTPUT PARAMETERS: ===================================================
      _RL freefe(1-OLx:sNx+OLx,1-OLy:sNy+OLy,Nr)
      _RL kscavin(1-OLx:sNx+OLx,1-OLy:sNy+OLy,Nr)
      _RL FEremin_inorg(1-OLx:sNx+OLx,1-OLy:sNy+OLy,Nr)
      _RL WFE_inorg(1-OLx:sNx+OLx,1-OLy:sNy+OLy,Nr)

#ifdef ALLOW_PTRACERS

C !LOCAL VARIABLES: ====================================================
C  i,j,k                  :: loop indices
c  ko                     :: loop-within-loop index
c  bexport                :: flux of phosphorus from base each "productive"
c                            layer
c  depth_u, depth_l       :: depths of upper and lower interfaces
c  flux_u, flux_l         :: flux through upper and lower interfaces
c  zbase                  :: depth of bottom of current productive layer
       _RL zbase
       _RL bexport(1-OLx:sNx+OLx,1-OLy:sNy+OLy)
       _RL irondust(1-OLx:sNx+OLx,1-OLy:sNy+OLy)
       INTEGER I,J,k, ko, kop1, maskp1
       _RL depth_u, depth_l
       _RL flux_u, flux_l
CEOP

C- Calculate WFE_inorg flux from base of each layer
       DO j=jmin,jmax
        DO i=imin,imax 

         Irondust(i,j)= alpfe*
     &             InputFe(i,j,bi,bj)*recip_drF(1)
     &            *recip_hFacC(i,j,1,bi,bj)

         DO k=1,Nr

          IF (hFacC(i,j,k,bi,bj).gt.0. _d 0) THEN
              IF ( k .EQ. 1 ) THEN
                  Kscavin(i,j,k) = Kscavin_const*
     &                   ((Irondust(i,j)/1.0409e-11)**1.5)

              IF (Kscavin(i,j,k).lt.2.  _d -7) THEN
                  Kscavin(i,j,k) = 2.  _d -7
              ENDIF

              ELSE
                  Kscavin(i,j,k) = Kscavin_const
              ENDIF

C- flux out of layer k
           bexport(i,j)=Kscavin(i,j,k)*freefe(i,j,k)*
     &                  drF(k)*hFacC(i,j,k,bi,bj)

C- calculate flux to each layer from base of k

C- if no layer below initial layer (because of bottom or
C- topography), then the iron flux is buried into the sediment, i.e. 
C  there is no iron being inorganically remineralized

           IF (k.EQ.Nr) THEN
             FEremin_inorg(i,j,k)=0.0
 
           ELSEIF (hFacC(i,j,k+1,bi,bj).EQ.0. _d 0) THEN
             FEremin_inorg(i,j,k)=0.0 

           ELSE

C- else, let's flux it downward

             zbase=-rF(k+1)
             DO ko=k+1,Nr
C- Upper flux
              IF (ko.EQ.k+1) THEN
                 depth_u = zbase
                 flux_u  = bexport(i,j)
              ELSE
                 depth_u = depth_l
                 flux_u  = flux_l
              ENDIF

C- Lower flux (no flux to ocean bottom)
              depth_l=depth_u+
     &                  drF(ko)*hFacC(i,j,ko,bi,bj)
              kop1 = MIN(Nr,ko+1)
              flux_l=bexport(i,j)*((depth_l/zbase)**(-Kremin_inorg))
     &              *maskC(i,j,kop1,bi,bj)
              WFE_inorg(i,j,ko)=WFE_inorg(i,j,ko)+flux_u
              FEremin_inorg(i,j,ko)=FEremin_inorg(i,j,ko) +
     &          (flux_u-flux_l)*recip_drF(ko)*recip_hFacC(i,j,ko,bi,bj)
             ENDDO

           ENDIF
          ENDIF
         ENDDO
        ENDDO
       ENDDO

#endif
       RETURN
       END
